using FitConnect.Models;

namespace FitConnect.Interfaces;

public interface IFluentApi<out T> {
    public T Authenticate(string clientId, string clientSecret, string? scope = null);
}

public interface IFluentSender {
    public IFluentSenderWithDestination WithDestination(string destinationId);
    public IFluentSenderWithAttachments WithAttachments(IEnumerable<Attachment> attachments);
    public IFluentSenderWithData WithData(string data);
    public Submission Submit();
}

public interface IFluentSenderWithDestination {
    public IFluentSenderWithAttachments WithAttachments(IEnumerable<Attachment> attachments);
}

public interface IFluentSenderWithAttachments : IFluentSenderReady {
    public IFluentSenderWithData WithData(string data);
}

public interface IFluentSenderWithData : IFluentSenderReady {
}

public interface IFluentSenderReady {
    public IFluentSender Submit();
}

public interface IFluentSubscriber {
    public IEnumerable<string> GetAvailableSubmissions();
    public IFluentSubscriberWithSubmission RequestSubmission(string submissionId);
}

public interface IFluentSubscriberWithSubmission {
    public Submission Submission { get; }

    public IFluentSenderWithAttachments GetAttachments(
        Func<IEnumerable<Attachment>, bool> canSubmitSubmission);

    public void ConfirmSubmission(string submissionId);
}
